"""
 Testing package for auth.credential

 Copyright (C) 2013 CERN
"""

import os
import sys

sys.path.insert(0, os.path.split(__file__)[0])

__all__ = list()
